@@ -9,14 +9,13 @@ package CGI::FormBuilder::Messages::locale;
 use strict;
 use utf8;
 
-use CGI::FormBuilder::Util;
+use CGI::FormBuilder::Messages::default;
+use base 'CGI::FormBuilder::Messages::default';
 
-our $REVISION = do { (my $r='$Revision: 100 $') =~ s/\D+//g; $r };
-our $VERSION = '3.06';
+our $VERSION = '3.08';
 
-# First, create a hash of messages for this language
-# Then, change "locale" to the 2-letter country code, such as "en" or "de"
-our %MESSAGES = (
+# Define messages for this language
+__PACKAGE__->define_messages({
     lang                  => 'da_DK',
     charset               => 'utf-8',
 
@@ -66,12 +65,7 @@ Hvis du har spørgsmål, så kontakt venligst vore medarbejdere
 ved at besvare denne email.
 EOT
     mail_results_subject  => '%s indsendelsesresultat',
-);
-
-# This method should remain unchanged
-sub messages {
-    return wantarray ? %MESSAGES : \%MESSAGES;
-}
+});
 
 1;
 __END__
