@@ -9,11 +9,13 @@ package CGI::FormBuilder::Messages::locale;
 use strict;
 use utf8;
 
-our $REVISION = do { (my $r='$Revision: 100 $') =~ s/\D+//g; $r };
-our $VERSION = '3.06';
+use CGI::FormBuilder::Messages::default;
+use base 'CGI::FormBuilder::Messages::default';
 
-# Simply create a hash of messages for this language
-our %MESSAGES = (
+our $VERSION = '3.08';
+
+# Define messages for this language
+__PACKAGE__->define_messages({
     lang                  => 'fr_FR',
     charset               => 'utf-8',
 
@@ -65,12 +67,7 @@ Pour toute question, veuillez contacter nos services
 en répondant à cet email.'
 EOT
     mail_results_subject  => 'Résultats du formulaire %s',
-);
-
-# This method should remain unchanged
-sub messages {
-    return wantarray ? %MESSAGES : \%MESSAGES;
-}
+});
 
 1;
 __END__
