@@ -1,7 +1,7 @@
 
 ###########################################################################
-# Copyright (c) 2000-2006 Nate Wiger <nate@wiger.org>. All Rights Reserved.
-# Please visit www.formbuilder.org for tutorials, support, and examples.
+# Copyright (c) Nate Wiger http://nateware.com. All Rights Reserved.
+# Please visit http://formbuilder.org for tutorials, support, and examples.
 ###########################################################################
 
 package CGI::FormBuilder::Messages::locale;
@@ -9,11 +9,13 @@ package CGI::FormBuilder::Messages::locale;
 use strict;
 use utf8;
 
-our $REVISION = do { (my $r='$Revision: 94 $') =~ s/\D+//g; $r };
-our $VERSION = '3.05';
+use CGI::FormBuilder::Messages::default;
+use base 'CGI::FormBuilder::Messages::default';
 
-# Simple create a hash of messages for this language
-our %MESSAGES = (
+our $VERSION = '3.08';
+
+# Define messages for this language
+__PACKAGE__->define_messages({
     lang                  => 'tr_TR',
     charset               => 'utf-8',
 
@@ -65,12 +67,7 @@ Eğer sorunuz varsa, lütfen bu iletiye cevap yazarak ekibimizle
 irtibat kurun.
 EOT
     mail_results_subject  => '%s Gönderi Sonuçları',
-);
-
-# This method should remain unchanged
-sub messages {
-    return wantarray ? %MESSAGES : \%MESSAGES;
-}
+});
 
 1;
 __END__
